@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from honeybee_radiance_folder import ModelFolder as Folder
+from honeybee_radiance_folder.folderutil import _as_posix
 import honeybee_radiance_folder.config as config
 import os
 import shutil
@@ -17,7 +18,7 @@ def test_writer():
     assert os.path.isdir(root_folder)
     subfolders = [
         f for f in os.listdir(root_folder)
-        if os.path.isdir(os.path.join(root_folder, f))
+        if os.path.isdir(_as_posix(os.path.join(root_folder, f)))
     ]
 
     cfg_names = ['GRID', 'VIEW'] + [k for k, v in config.minimal.items() if v is True]
@@ -43,7 +44,7 @@ def test_writer_model_folder():
     assert os.path.isdir(root_folder)
     subfolders = [
         f for f in os.listdir(root_folder)
-        if os.path.isdir(os.path.join(root_folder, f))
+        if os.path.isdir(_as_posix(os.path.join(root_folder, f)))
     ]
 
     cfg_names = ['GRID', 'VIEW'] + [k for k, v in config.minimal.items() if v is True]
@@ -61,18 +62,20 @@ def test_reader():
     radiance_folder = r'./tests/assets/project_folder'
     rad_folder = Folder(radiance_folder)
     assert rad_folder.model_folder() == 'model'
-    assert rad_folder.aperture_folder() == os.path.join('model', 'aperture')
-    assert rad_folder.aperture_group_folder() == os.path.join('model', 'aperture_group')
+    assert rad_folder.aperture_folder() == _as_posix(os.path.join('model', 'aperture'))
+    assert rad_folder.aperture_group_folder() == \
+        _as_posix(os.path.join('model', 'aperture_group'))
     assert rad_folder.aperture_group_folder(interior=True) == \
-        os.path.join('model', 'aperture_group', 'interior')
-    assert rad_folder.bsdf_folder() == os.path.join('model', 'bsdf')
-    assert rad_folder.grid_folder() == os.path.join('model', 'grid')
-    assert rad_folder.ies_folder() == os.path.join('model', 'ies')
-    assert rad_folder.scene_folder() == os.path.join('model', 'scene')
-    assert rad_folder.dynamic_scene_folder() == os.path.join('model', 'scene_dynamic')
+        _as_posix(os.path.join('model', 'aperture_group', 'interior'))
+    assert rad_folder.bsdf_folder() == _as_posix(os.path.join('model', 'bsdf'))
+    assert rad_folder.grid_folder() == _as_posix(os.path.join('model', 'grid'))
+    assert rad_folder.ies_folder() == _as_posix(os.path.join('model', 'ies'))
+    assert rad_folder.scene_folder() == _as_posix(os.path.join('model', 'scene'))
+    assert rad_folder.dynamic_scene_folder() == \
+        _as_posix(os.path.join('model', 'scene_dynamic'))
     assert rad_folder.dynamic_scene_folder(indoor=True) == \
-        os.path.join('model', 'scene_dynamic', 'indoor')
-    assert rad_folder.view_folder() == os.path.join('model', 'view')
+        _as_posix(os.path.join('model', 'scene_dynamic', 'indoor'))
+    assert rad_folder.view_folder() == _as_posix(os.path.join('model', 'view'))
 
 
 def test_reader_files():
@@ -81,24 +84,18 @@ def test_reader_files():
     assert rad_folder.has_aperture_group
     assert not rad_folder.has_dynamic_scene
     assert rad_folder.aperture_files() == [
-        os.path.normpath(f) for f in [
-            'model/aperture/aperture.mat', 'model/aperture/aperture.rad'
-        ]
+        'model/aperture/aperture.mat', 'model/aperture/aperture.rad'
     ]
     assert rad_folder.aperture_files(black_out=True) == [
-        os.path.normpath(f) for f in [
-            'model/aperture/aperture.blk', 'model/aperture/aperture.rad'
-        ]
+        'model/aperture/aperture.blk', 'model/aperture/aperture.rad'
     ]
 
     s_files = rad_folder.scene_files()
     e_files = [
-        os.path.normpath(f) for f in [
-            'model/scene/context.mat', 'model/scene/context.rad',
-            'model/scene/partition.mat', 'model/scene/partition.rad',
-            'model/scene/partition_glass.mat', 'model/scene/partition_glass.rad',
-            'model/scene/room_envelope.mat', 'model/scene/room_envelope.rad'
-        ]
+        'model/scene/context.mat', 'model/scene/context.rad',
+        'model/scene/partition.mat', 'model/scene/partition.rad',
+        'model/scene/partition_glass.mat', 'model/scene/partition_glass.rad',
+        'model/scene/room_envelope.mat', 'model/scene/room_envelope.rad'
     ]
     assert s_files.index(e_files[1]) - s_files.index(e_files[0]) == 1
     assert s_files.index(e_files[3]) - s_files.index(e_files[2]) == 1
@@ -107,12 +104,10 @@ def test_reader_files():
 
     s_files = rad_folder.scene_files(black_out=True)
     e_files = [
-        os.path.normpath(f) for f in [
-            'model/scene/context.blk', 'model/scene/context.rad',
-            'model/scene/partition.blk', 'model/scene/partition.rad',
-            'model/scene/partition_glass.blk', 'model/scene/partition_glass.rad',
-            'model/scene/room_envelope.blk', 'model/scene/room_envelope.rad'
-        ]
+        'model/scene/context.blk', 'model/scene/context.rad',
+        'model/scene/partition.blk', 'model/scene/partition.rad',
+        'model/scene/partition_glass.blk', 'model/scene/partition_glass.rad',
+        'model/scene/room_envelope.blk', 'model/scene/room_envelope.rad'
     ]
     assert s_files.index(e_files[1]) - s_files.index(e_files[0]) == 1
     assert s_files.index(e_files[3]) - s_files.index(e_files[2]) == 1
